:orphan:

This folder contains test sources.

It is catagorized in directories:

* `common` - tests of common reStructuredText markup.
* `directives` - tests of general reStructuredText directives.
* `roles` - tests of general reStructuredText roles.
* `sphinx-directives` - tests of Sphinx-specific reStructuredText directives.
* `sphinx-roles` - tests of Sphinx-specific reStructuredText roles.
